
#ifndef _C14_ds679_
#define _C14_ds679_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1100_7465(EIF_REFERENCE);
extern void EIF_Minit679(void);

#ifdef __cplusplus
}
#endif

#endif
